@@ -949,6 +949,62 @@ static void *xjadeo (void *arg) {
 	return NULL;
 }
 
+#if defined PLATFORM_WINDOWS
+static FILE* pStdOut = 0;
+static FILE* pStdErr = 0;
+static BOOL  bConsole;
+static HANDLE hStdOut;
+
+static int
+IsAConsolePort (HANDLE handle)
+{
+	DWORD mode;
+	return (GetConsoleMode(handle, &mode) != 0);
+}
+
+static void
+console_madness_begin ()
+{
+	bConsole = AttachConsole(ATTACH_PARENT_PROCESS);
+	hStdOut = GetStdHandle(STD_OUTPUT_HANDLE);
+
+	/* re-attach to the console so we can see 'printf()' output etc.  */
+	if ((bConsole) && (IsAConsolePort(hStdOut))) {
+		pStdOut = freopen( "CONOUT$", "w", stdout );
+		pStdErr = freopen( "CONOUT$", "w", stderr );
+	}
+}
+
+static void
+console_madness_end ()
+{
+	if (pStdOut) {
+		fclose (pStdOut);
+	}
+	if (pStdErr) {
+		fclose (pStdErr);
+	}
+
+	if (bConsole) {
+		/* Detach and free the console from our application, and line feed */
+		INPUT_RECORD input_record;
+
+		input_record.EventType = KEY_EVENT;
+		input_record.Event.KeyEvent.bKeyDown = TRUE;
+		input_record.Event.KeyEvent.dwControlKeyState = 0;
+		input_record.Event.KeyEvent.uChar.UnicodeChar = VK_RETURN;
+		input_record.Event.KeyEvent.wRepeatCount      = 1;
+		input_record.Event.KeyEvent.wVirtualKeyCode   = VK_RETURN;
+		input_record.Event.KeyEvent.wVirtualScanCode  = MapVirtualKey( VK_RETURN, 0 );
+
+		DWORD written = 0;
+		WriteConsoleInput( GetStdHandle( STD_INPUT_HANDLE ), &input_record, 1, &written );
+
+		FreeConsole();
+	}
+}
+#endif
+
 
 #if defined PLATFORM_WINDOWS && defined USE_WINMAIN
 
@@ -1003,6 +1059,10 @@ int main (int argc, char **argv)
 	int i;
 	char *movie;
 
+#ifdef PLATFORM_WINDOWS
+	console_madness_begin ();
+#endif
+
 	xjadeorc(); // read config files - default values before parsing cmd line.
 
 #ifdef PLATFORM_OSX
@@ -1062,7 +1122,7 @@ int main (int argc, char **argv)
 			strcpy(OSD_fontfile, path);
 			strcat(OSD_fontfile, "\\" FONT_FILE);
 		} else {
-			GetModuleFileNameW(NULL, (LPWCH)path, MAX_PATH);
+			GetModuleFileName(NULL, (LPWCH)path, MAX_PATH);
 			char *tmp;
 			if ((tmp = strrchr(path, '\\'))) *tmp = 0;
 			strcpy(OSD_fontfile, path);
@@ -1115,5 +1175,9 @@ int main (int argc, char **argv)
 #endif
 
 	clean_up(0);
+
+#ifdef PLATFORM_WINDOWS
+	console_madness_end ();
+#endif
 	return (0);
 }
